@@ -467,7 +467,8 @@ class Mocket:
 
         if truesocket_recording_dir:
             # JSON dumps will be saved here
-            assert os.path.isdir(truesocket_recording_dir)
+            if not os.path.isdir(truesocket_recording_dir):
+                raise AssertionError
 
         socket.socket = socket.__dict__["socket"] = MocketSocket
         socket._socketobject = socket.__dict__["_socketobject"] = MocketSocket
@@ -547,9 +548,8 @@ class Mocket:
     @classmethod
     def assert_fail_if_entries_not_served(cls):
         """Mocket checks that all entries have been served at least once."""
-        assert all(
-            entry._served for entry in itertools.chain(*cls._entries.values())
-        ), "Some Mocket entries have not been served"
+        if not all(entry._served for entry in itertools.chain(*cls._entries.values())):
+            raise AssertionError("Some Mocket entries have not been served")
 
 
 class MocketEntry:
@@ -559,7 +559,7 @@ class MocketEntry:
             return self
 
     response_index = 0
-    request_cls = str
+    request_cls = byte_type
     response_cls = Response
     responses = None
     _served = None
